@@ -38,6 +38,11 @@ class Playlist(BaseModel):
                 return uri
         return None
 
+    def get_uri(self, service_name: str) -> Optional[PlaylistURIs]:
+        if service_name in self.uris:
+            return self.uris[service_name]
+        return None
+
     def set_uri(self, service_name: str, uri: PlaylistURIs) -> None:
         self.uris[service_name] = uri
 
